@@ -1,28 +1,25 @@
 use strict;
 use warnings;
 package Task::Tapper::Hello::World;
-# git description: v0.001-2-ga1c0b2c
+# git description: v0.002-1-gb7a3b9e
 
-BEGIN {
-  $Task::Tapper::Hello::World::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Task::Tapper::Hello::World::VERSION = '0.002';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - The easiest start without hassle (hopefully)
-
-
+$Task::Tapper::Hello::World::VERSION = '0.003';
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Task::Tapper::Hello::World - Tapper - The easiest start without hassle (hopefully)
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 TASK CONTENTS
 
@@ -60,8 +57,6 @@ version 0.002
 
 =head3 L<Tapper::TestSuite::AutoTest>
 
-=head3 L<Tapper::TestSuite::Benchmark::Perl::Formance>
-
 =head3 L<Tapper::TestSuite::HWTrack>
 
 =head3 L<Tapper::MCP>
@@ -70,6 +65,8 @@ version 0.002
 
 =head3 L<Task::Tapper::Client>
 
+=head3 L<Tapper::Reports::Receiver::Level2::BenchmarkAnything>
+
 1;
 
 =head1 AUTHOR
@@ -78,11 +75,10 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Steffen Schwigon.
+This software is Copyright (c) 2016 by Steffen Schwigon.
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
